@@ -4,7 +4,7 @@
 # Copyright 2013 Giuseppe Venturini
 # This file is part of python-deltasigma.
 #
-# python-deltasigma is a 1:1 Python replacement of Richard Schreier's 
+# python-deltasigma is a 1:1 Python replacement of Richard Schreier's
 # MATLAB delta sigma toolbox (aka "delsigma"), upon which it is heavily based.
 # The delta sigma toolbox is (c) 2009, Richard Schreier.
 #
@@ -27,6 +27,7 @@ from numpy.linalg import norm
 from ._dbp import dbp
 from ._utils import carray
 
+
 def bilogplot(V, f0, fbin, x, y, **fmt):
     """Plot the spectrum of a band-pass modulator in dB.
 
@@ -65,7 +66,7 @@ def bilogplot(V, f0, fbin, x, y, **fmt):
     y : 3-elements sequence-like
         y is a sequence of three floats: ``ymin``, ``ymax``, ``dy``.
         ``ymin`` is the minimum value of the y-axis, ``ymax`` its maximum value and
-        ``dy`` is the ticks spacing. 
+        ``dy`` is the ticks spacing.
 
     .. note::
         The MATLAB Delta Sigma toolbox allows for a fourth option ``y_skip``, which
@@ -75,7 +76,7 @@ def bilogplot(V, f0, fbin, x, y, **fmt):
     Additional keyword parameters ``**fmt`` will be passed to matplotlib's ``semilogx()``.
 
     The FFT is smoothed before plotting and converted to dB. See
-    :func:`logsmooth` for details regarding the algorithm used. 
+    :func:`logsmooth` for details regarding the algorithm used.
 
     **Returns:**
 
@@ -106,8 +107,8 @@ def bilogplot(V, f0, fbin, x, y, **fmt):
     V = carray(V)
     if len(V.shape) > 1:
         if np.prod(V.shape) > max(V.shape):
-            raise ValueError("The input value V should have only one" + \
-                            " non-unitary dimension.") 
+            raise ValueError("The input value V should have only one" +
+                             " non-unitary dimension.")
         V = V.squeeze()
     Xl = V[f0::-1]
     Xr = V[f0:]
@@ -118,10 +119,10 @@ def bilogplot(V, f0, fbin, x, y, **fmt):
     p = np.concatenate((pl[::-1], pr))
     f = np.concatenate((-fl[::-1], fr))
     plt.plot(f, p, **fmt)
-    plt.xscale('symlog', linthreshx=x[0], 
-               subsx=np.logspace(10**int(np.ceil(np.log10(x[0]))), 
+    plt.xscale('symlog', linthreshx=x[0],
+               subsx=np.logspace(10**int(np.ceil(np.log10(x[0]))),
                                  10**int(1+np.ceil(np.log10(max(x[2], x[1])))))
-              )
+               )
     ax = plt.gca()
     ax.set_xlim([-x[1], x[2]])
     ax.set_ylim([y[0], y[1]])
@@ -129,26 +130,27 @@ def bilogplot(V, f0, fbin, x, y, **fmt):
     ytix = range(y[0], y[1] + 1, y[2])
     ax.yaxis.set_ticks(ytix)
     # we do not support axis labels
-    #set_(gca,'YTickLabel', axisLabels(ytix, y[3]))
+    # set_(gca,'YTickLabel', axisLabels(ytix, y[3]))
     #
     if len(y) == 4 and not y[3] is None:
-        warn("Specifying y_skip is not currently supported and " + \
+        warn("Specifying y_skip is not currently supported and " +
              "it will be ignored. Sorry!")
     return
 
+
 def _logsmooth2(X, inBin, nbin=8):
     """Smooth the fft, X, and convert it to dB.
-    Use ``nbin`` bins from 0 to 3*inBin, 
+    Use ``nbin`` bins from 0 to 3*inBin,
     thereafter increase bin sizes by a factor of 1.1, staying less than 2^10.
-    For the 3 sets of bins inBin+[0:2], 2*inBin+[0:2], and 
+    For the 3 sets of bins inBin+[0:2], 2*inBin+[0:2], and
     3*inBin+[0:2], don't do averaging. This way, the noise BW
     and the scaling of the tone and its harmonics are unchanged.
-    Unfortunately, harmonics above the third appear smaller than they 
+    Unfortunately, harmonics above the third appear smaller than they
     really are because their energy is averaged over several bins.
-    """    
+    """
     N = max(X.shape)
     n = nbin
-    f1 = int((inBin - 1) %  n) + 1
+    f1 = int((inBin - 1) % n) + 1
     startbin = np.concatenate((np.arange(f1, inBin, n),
                                np.arange(inBin, inBin + 3),
                                np.arange(inBin + 3, 2*inBin, n),
@@ -165,10 +167,12 @@ def _logsmooth2(X, inBin, nbin=8):
     p = np.zeros(f.shape)
     for i in range(max(f.shape)):
         p[i] = 10*np.log10(norm(X[(startbin[i] - 1):stopbin[i]])**2 /
-                   (stopbin[i] - startbin[i] + 1))
+                           (stopbin[i] - startbin[i] + 1))
     return f, p
 
+
 def test_bilogplot():
+    """Test function for bilogplot()"""
     from ._synthesizeNTF import synthesizeNTF
     from ._simulateDSM import simulateDSM
     from ._calculateSNR import calculateSNR
@@ -186,3 +190,4 @@ def test_bilogplot():
     X = spec[:N/2 + 1]
     plt.figure()
     bilogplot(X, f0*N, ftest, (.03, .3, .3), (-140, 0, 10))
+    # graphical function: we check it doesn't fail
