@@ -96,37 +96,3 @@ def partitionABCD(ABCD, m=None):
     D = ABCD[n:n+r, n:n+m]
     return A, B, C, D
 
-def test_partitionABCD():
-    """Test function for partitionABCD()"""
-    import numpy as np
-    from scipy.signal import lti
-    ob = lti((1, ), (1, 2, 10))
-    ab = np.hstack((ob.A, ob.B))
-    cd = np.hstack((ob.C, ob.D.reshape((1,1))))
-    abcd = np.vstack((ab, cd))
-    a, b, c, d = partitionABCD(abcd)
-    assert np.allclose(a, ob.A, rtol=1e-5, atol=1e-8)
-    assert np.allclose(b, ob.B, rtol=1e-5, atol=1e-8)
-    assert np.allclose(c, ob.C, rtol=1e-5, atol=1e-8)
-    assert np.allclose(d, ob.D, rtol=1e-5, atol=1e-8)
-    ABCD = [[1.000000000000000, 0., 0., 0.044408783846879, -0.044408783846879],
-            [0.999036450096481, 0.997109907515262, -0.005777399147297, 0., 0.499759089304780],
-            [0.499759089304780, 0.999036450096481, 0.997109907515262,  0., -0.260002096136488],
-            [0,                 0,                 1.000000000000000,  0, -0.796730400347216]]
-    ABCD = np.array(ABCD)
-    at = np.array([[1., 0., 0.],
-                   [0.999036450096481, 0.997109907515262, -0.005777399147297],
-                   [0.499759089304780, 0.999036450096481,  0.997109907515262]
-                  ])
-    bt = np.array([[0.044408783846879, -0.044408783846879],
-                   [0., 0.499759089304780],
-                   [0., -0.260002096136488]
-                  ])
-    ct = np.array([0., 0, 1])
-    dt = np.array([0., -0.796730400347216])
-    ar, br, cr, dr = partitionABCD(ABCD, m=2)
-    assert np.allclose(at, ar, rtol=1e-5, atol=1e-8)
-    assert np.allclose(bt, br, rtol=1e-5, atol=1e-8)
-    assert np.allclose(ct, cr, rtol=1e-5, atol=1e-8)
-    assert np.allclose(dt, dr, rtol=1e-5, atol=1e-8)
-
